Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var FileProcessors = map[string]FileProcessorFactory{ "hash": func() FileProcessor { return processors.NewHasher() }, }
FileProcessors is the list of available file processor factories. Each call produces a fresh instance to avoid shared mutable state.
Functions ¶
This section is empty.
Types ¶
type Decomposer ¶
type Decomposer struct {
Options options.Options
Processors []FileProcessor
}
Decomposer is a filesystem indexer
func (*Decomposer) Extract ¶
func (d *Decomposer) Extract(*api.DecomposerOptions) (*sbom.NodeList, error)
Extract reads and hashes the files from the filesystem
type FileProcessor ¶
type FileProcessorFactory ¶ added in v0.1.1
type FileProcessorFactory func() FileProcessor
FileProcessorFactory is a function that creates a new FileProcessor instance.
Click to show internal directories.
Click to hide internal directories.